==> sidecar-0.1.0-dev.10.tar.gz: lib/src/configurations/rule_package/rule_package_configuration.dart <==
import 'dart:io';

import 'package:checked_yaml/checked_yaml.dart';
import 'package:path/path.dart' as p;
import 'package:yaml/yaml.dart';

import '../../utils/file_paths.dart';
import 'rule_yaml_nodes.dart';

// @JsonSerializable(anyMap: true)
class RulePackageConfiguration {
  RulePackageConfiguration(
    this.yamlLints,
    this.yamlAssists, {
    required this.source,
    required this.packageName,
    required this.uri,
  });

  factory RulePackageConfiguration.fromYamlMap(
    YamlMap map, {
    required Uri uri,
    required String packageName,
  }) {
    return RulePackageConfiguration(
      map['lints'] as YamlList?,
      map['assists'] as YamlList?,
      source: map,
      uri: uri,
      packageName: packageName,
    );
  }

  final YamlList? yamlLints;
  final YamlList? yamlAssists;
  final YamlMap source;

  final String packageName;
  final Uri uri;

  List<LintNode>? get lints => yamlLints?.nodes.map(LintNode.new).toList();
  List<AssistNode>? get assists =>
      yamlAssists?.nodes.map(AssistNode.new).toList();
}

RulePackageConfiguration? parseLintPackage(String name, Uri root) {
  final rootPath = root.toFilePath(windows: Platform.isWindows);
  final pubspecPath = p.join(rootPath, kPubspecYaml);
  final pubspecContent = File(pubspecPath).readAsStringSync();
  try {
    return checkedYamlDecode<RulePackageConfiguration?>(pubspecContent,
        (yamlMap) {
      if (yamlMap?['sidecar'] == null) return null;
      return RulePackageConfiguration.fromYamlMap(
        yamlMap!['sidecar']! as YamlMap,
        uri: root,
        packageName: name,
      );
    });
  } catch (e) {
    return null;
  }
}

==> sidecar-0.1.8.tar.gz: lib/src/configurations/rule_package/rule_package_configuration.dart <==
import 'dart:io';

import 'package:checked_yaml/checked_yaml.dart';
import 'package:path/path.dart' as p;
import 'package:yaml/yaml.dart';

import '../../utils/file_paths.dart';
import 'rule_yaml_nodes.dart';

// @JsonSerializable(anyMap: true)a
class RulePackageConfiguration {
  RulePackageConfiguration(
    this.yamlLints,
    this.yamlAssists, {
    required this.source,
    required this.packageName,
    required this.uri,
  });

  factory RulePackageConfiguration.fromYamlMap(
    YamlMap map, {
    required Uri uri,
    required String packageName,
  }) {
    return RulePackageConfiguration(
      map['lints'] as YamlList?,
      map['assists'] as YamlList?,
      source: map,
      uri: uri,
      packageName: packageName,
    );
  }

  final YamlList? yamlLints;

  final YamlList? yamlAssists;

  final YamlMap source;

  final String packageName;

  final Uri uri;

  List<LintNode>? get lints => yamlLints?.nodes.map(LintNode.new).toList();

  List<AssistNode>? get assists =>
      yamlAssists?.nodes.map(AssistNode.new).toList();
}

RulePackageConfiguration? parseLintPackage(String name, Uri root) {
  final rootPath = root.toFilePath(windows: Platform.isWindows);
  final pubspecPath = p.join(rootPath, kPubspecYaml);
  final pubspecContent = File(pubspecPath).readAsStringSync();
  try {
    return checkedYamlDecode<RulePackageConfiguration?>(pubspecContent,
        (yamlMap) {
      if (yamlMap?['sidecar'] == null) return null;
      return RulePackageConfiguration.fromYamlMap(
        yamlMap!['sidecar']! as YamlMap,
        uri: root,
        packageName: name,
      );
    });
  } catch (e) {
    return null;
  }
}
